@@ -18,7 +18,11 @@ class _BaseModule:
         mkpiano.quit()
 
     def setup(self,board,idx,mode=1,period=0):
-        board._autoconnect()
+        if board._autoconnect()==False:
+            print("\033[1;33m连接失败，未检测到设备\033[0m")
+            self.quit()
+        else:
+            print("\033[1;32m连接成功，正在运行程序...\033[0m")
         self._board = board
         self._mode = mode
         self._pack = NeuronPackData()
@@ -39,8 +43,8 @@ class _BaseModule:
     def call(self,pack):
         self._board.call(pack)
 
-    def _exist_subscribe(self,subscribe_id):
-        return self._board._find_subscribe(subscribe_id)
+    def _exist_subscribe(self,subscribe_id,cmd):
+        return self._board._find_subscribe(subscribe_id,cmd)
 
     def subscribe(self,pack=None):
         pass
@@ -48,7 +52,7 @@ class _BaseModule:
     def _subscribe(self,idx,service,subservice,on_response,data=None):
         data = data or self._default_data
         subscribe_id = (idx<<24)+(service<<16)+(subservice<<8)
-        if self._exist_subscribe(subscribe_id):
+        if self._exist_subscribe(subscribe_id,data[0]):
             return subscribe_id
         pack = NeuronPackData()
         pack.on_response = on_response
@@ -56,6 +60,7 @@ class _BaseModule:
         pack.service = service
         pack.subservice = subservice
         pack.data = data
+        pack.cmd = data[0]
         pack.subscribe_id = subscribe_id
         self._board.request(pack)
         return subscribe_id
